==> estateplat-common-1.2.4-20200319.132235-285-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjCbzdCbf.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;

/**
 * Created by IntelliJ IDEA.
 * User: zx
 * Date: 15-5-8
 * Time: 下午7:16
 * To change this template use File | Settings | File Templates.
 * dos:土地承包经营权--承包方
 */
public class DjsjCbzdCbf {
    private String cbzdCbfIndex;
    private String cbfmc;
    private String ywcbht;
    private String cbhtbh;
    private String ywjyqz;
    private String jyqzbh;
    private String qdcbfs;
    private Date gxrq;
    private String zddcbIndex;

    public String getCbzdCbfIndex() {
        return cbzdCbfIndex;
    }

    public void setCbzdCbfIndex(String cbzdCbfIndex) {
        this.cbzdCbfIndex = cbzdCbfIndex;
    }

    public String getCbfmc() {
        return cbfmc;
    }

    public void setCbfmc(String cbfmc) {
        this.cbfmc = cbfmc;
    }

    public String getYwcbht() {
        return ywcbht;
    }

    public void setYwcbht(String ywcbht) {
        this.ywcbht = ywcbht;
    }

    public String getCbhtbh() {
        return cbhtbh;
    }

    public void setCbhtbh(String cbhtbh) {
        this.cbhtbh = cbhtbh;
    }

    public String getYwjyqz() {
        return ywjyqz;
    }

    public void setYwjyqz(String ywjyqz) {
        this.ywjyqz = ywjyqz;
    }

    public String getJyqzbh() {
        return jyqzbh;
    }

    public void setJyqzbh(String jyqzbh) {
        this.jyqzbh = jyqzbh;
    }

    public String getQdcbfs() {
        return qdcbfs;
    }

    public void setQdcbfs(String qdcbfs) {
        this.qdcbfs = qdcbfs;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getZddcbIndex() {
        return zddcbIndex;
    }

    public void setZddcbIndex(String zddcbIndex) {
        this.zddcbIndex = zddcbIndex;
    }
}

==> estateplat-common-1.2.4-20201210.022956-586-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjCbzdCbf.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;

/**
 * Created by IntelliJ IDEA.
 * User: zx
 * Date: 15-5-8
 * Time: 下午7:16
 * To change this template use File | Settings | File Templates.
 * dos:土地承包经营权--承包方
 */
public class DjsjCbzdCbf {
    private String cbzdCbfIndex;
    private String cbfmc;
    private String ywcbht;
    private String cbhtbh;
    private String ywjyqz;
    private String jyqzbh;
    private String qdcbfs;
    private Date gxrq;
    private String zddcbIndex;
    private String cbfzjlx;//承包方证件类型
    private String cbfzjhm;//承包方证件号


    public String getCbzdCbfIndex() {
        return cbzdCbfIndex;
    }

    public void setCbzdCbfIndex(String cbzdCbfIndex) {
        this.cbzdCbfIndex = cbzdCbfIndex;
    }

    public String getCbfmc() {
        return cbfmc;
    }

    public void setCbfmc(String cbfmc) {
        this.cbfmc = cbfmc;
    }

    public String getYwcbht() {
        return ywcbht;
    }

    public void setYwcbht(String ywcbht) {
        this.ywcbht = ywcbht;
    }

    public String getCbhtbh() {
        return cbhtbh;
    }

    public void setCbhtbh(String cbhtbh) {
        this.cbhtbh = cbhtbh;
    }

    public String getYwjyqz() {
        return ywjyqz;
    }

    public void setYwjyqz(String ywjyqz) {
        this.ywjyqz = ywjyqz;
    }

    public String getJyqzbh() {
        return jyqzbh;
    }

    public void setJyqzbh(String jyqzbh) {
        this.jyqzbh = jyqzbh;
    }

    public String getQdcbfs() {
        return qdcbfs;
    }

    public void setQdcbfs(String qdcbfs) {
        this.qdcbfs = qdcbfs;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getZddcbIndex() {
        return zddcbIndex;
    }

    public void setZddcbIndex(String zddcbIndex) {
        this.zddcbIndex = zddcbIndex;
    }

    public String getCbfzjlx() {
        return cbfzjlx;
    }

    public void setCbfzjlx(String cbfzjlx) {
        this.cbfzjlx = cbfzjlx;
    }

    public String getCbfzjhm() {
        return cbfzjhm;
    }

    public void setCbfzjhm(String cbfzjhm) {
        this.cbfzjhm = cbfzjhm;
    }
}
